;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "acp" "20251116.1155"
  "An ACP (Agent Client Protocol) implementation."
  '((emacs "28.1"))
  :url "https://github.com/xenodium/acp.el"
  :commit "3c6a39c09684145b82721b506b80fa857664258a"
  :revdesc "3c6a39c09684")
